=== modified file 'NEWS'
--- NEWS	2011-02-10 17:01:10 +0000
+++ NEWS	2011-02-09 22:54:31 +0000
@@ -2,16 +2,11 @@
 =============================
 
 1.19 [???]
-----------------
-
-    - If we get a HEAD request, there is no reason to expand the template, we
-      shouldn't be returning body content anyway.
-      (John Arbash Meinel, #716201, #716217)
+----------
 
     - Merge the pqm changes back into trunk, after trunk was reverted to an old
       revision. (John Arbash Meinel, #716152)
 
-
 1.18 [10Nov2010]
 ----------------
 

=== modified file '__init__.py'
--- __init__.py	2011-02-10 01:57:32 +0000
+++ __init__.py	2011-02-09 21:17:32 +0000
@@ -42,7 +42,18 @@
 
     require_any_api(bzrlib, bzr_compatible_versions)
 
-    from bzrlib.transport import transport_server_registry
+    # NB: Normally plugins should lazily load almost everything, but this
+    # seems reasonable to have in-line here: bzrlib.commands and options are
+    # normally loaded, and the rest of loggerhead won't be loaded until serve
+    # --http is run.
+
+    # transport_server_registry was added in bzr 1.16. When we drop support for
+    # older releases, we can remove the code to override cmd_serve.
+
+    try:
+        from bzrlib.transport import transport_server_registry
+    except ImportError:
+        transport_server_registry = None
 
     DEFAULT_HOST = '0.0.0.0'
     DEFAULT_PORT = 8080
@@ -60,6 +71,7 @@
         logging.getLogger('simpleTAL').addHandler(handler)
         logging.getLogger('simpleTALES').addHandler(handler)
 
+
     def _ensure_loggerhead_path():
         """Ensure that you can 'import loggerhead' and get the root."""
         # loggerhead internal code will try to 'import loggerhead', so
@@ -92,27 +104,48 @@
         app = HTTPExceptionHandler(app)
         serve(app, host=host, port=port)
 
-    transport_server_registry.register('http', serve_http, help=HELP)
+    if transport_server_registry is not None:
+        transport_server_registry.register('http', serve_http, help=HELP)
+    else:
+        import bzrlib.builtins
+        from bzrlib.option import Option
+
+        _original_command = commands.get_cmd_object('serve')
+
+        class cmd_serve(bzrlib.builtins.cmd_serve):
+            __doc__ = _original_command.__doc__
+
+            takes_options = _original_command.takes_options + [
+                Option('http', help=HELP)]
+
+            def run(self, *args, **kw):
+                if 'http' in kw:
+                    from bzrlib.transport import get_transport
+                    allow_writes = kw.get('allow_writes', False)
+                    path = kw.get('directory', '.')
+                    port = kw.get('port', DEFAULT_PORT)
+                    # port might be an int already...
+                    if isinstance(port, basestring) and ':' in port:
+                        host, port = port.split(':')
+                    else:
+                        host = DEFAULT_HOST
+                    if allow_writes:
+                        transport = get_transport(path)
+                    else:
+                        transport = get_transport('readonly+' + path)
+                    serve_http(transport, host, port)
+                else:
+                    super(cmd_serve, self).run(*args, **kw)
+
+        commands.register_command(cmd_serve)
 
     class cmd_load_test_loggerhead(commands.Command):
         """Run a load test against a live loggerhead instance.
-
-        Pass in the name of a script file to run. See loggerhead/load_test.py
-        for a description of the file format.
         """
 
-        takes_args = ["filename"]
-
-        def run(self, filename):
+        def run(self):
             from bzrlib.plugins.loggerhead.loggerhead import load_test
-            script = load_test.run_script(filename)
-            for thread_id in sorted(script._threads):
-                worker = script._threads[thread_id][0]
-                for url, success, time in worker.stats:
-                    self.outf.write(' %5.3fs %s %s\n'
-                                    % (time, str(success)[0], url))
-
-    commands.register_command(cmd_load_test_loggerhead)
+            load_test.run()
 
     def load_tests(standard_tests, module, loader):
         _ensure_loggerhead_path()

=== removed directory 'load_test_scripts'
=== removed file 'load_test_scripts/multiple_instances.script'
--- load_test_scripts/multiple_instances.script	2011-02-10 01:00:32 +0000
+++ load_test_scripts/multiple_instances.script	1970-01-01 00:00:00 +0000
@@ -1,19 +0,0 @@
-{
-    "comment": "Connect to multiple loggerhead instances and make requests on each. One should be on :8080, one should be on :8081. Multiple threads will place requests on each.",
-    "parameters": {"base_url": "http://localhost"},
-    "requests": [
-        {"thread": "1", "relpath": ":8080/changes"},
-        {"thread": "2", "relpath": ":8080/files"},
-        {"thread": "3", "relpath": ":8081/files"},
-        {"thread": "4", "relpath": ":8081/changes"},
-        {"thread": "1", "relpath": ":8080/changes"},
-        {"thread": "2", "relpath": ":8080/files"},
-        {"thread": "3", "relpath": ":8081/files"},
-        {"thread": "4", "relpath": ":8081/changes"},
-        {"thread": "1", "relpath": ":8080/changes"},
-        {"thread": "2", "relpath": ":8080/files"},
-        {"thread": "3", "relpath": ":8081/files"},
-        {"thread": "4", "relpath": ":8081/changes"}
-    ]
-}
-

=== removed file 'load_test_scripts/simple.script'
--- load_test_scripts/simple.script	2011-02-10 01:00:32 +0000
+++ load_test_scripts/simple.script	1970-01-01 00:00:00 +0000
@@ -1,9 +0,0 @@
-{
-    "comment": "A fairly trivial load test script. It just loads the main two pages from a loggerhead install running directly on a branch.",
-    "parameters": {"base_url": "http://localhost:8080"},
-    "requests": [
-        {"relpath": "/changes"},
-        {"relpath": "/files"}
-    ]
-}
-

=== modified file 'loggerhead/controllers/__init__.py'
--- loggerhead/controllers/__init__.py	2011-02-10 17:01:10 +0000
+++ loggerhead/controllers/__init__.py	2011-01-20 07:28:21 +0000
@@ -99,9 +99,6 @@
         if 'Content-Type' not in headers:
             headers['Content-Type'] = 'text/html'
         writer = start_response("200 OK", headers.items())
-        if environ.get('REQUEST_METHOD') == 'HEAD':
-            # No content for a HEAD request
-            return []
         template = load_template(self.template_path)
         z = time.time()
         w = BufferingWriter(writer, 8192)

=== modified file 'loggerhead/load_test.py'
--- loggerhead/load_test.py	2011-02-10 01:00:32 +0000
+++ loggerhead/load_test.py	2011-02-10 00:23:33 +0000
@@ -78,11 +78,6 @@
     urlutils,
     )
 
-# This code will be doing multi-threaded requests against bzrlib.transport
-# code. We want to make sure to load everything ahead of time, so we don't get
-# lazy-import failures
-_ = transport.get_transport('http://example.com')
-
 
 class RequestDescription(object):
     """Describes info about a request."""
@@ -106,11 +101,6 @@
 
     def step_next(self):
         url = self.queue.get(True, self.blocking_time)
-        if url == '<noop>':
-            # This is usually an indicator that we want to stop, so just skip
-            # this one.
-            self.queue.task_done()
-            return
         self.start_time = self._timer()
         success = self.process(url)
         self.end_time = self._timer()
@@ -162,6 +152,8 @@
             raise ValueError('Missing "parameters" section')
         if 'requests' not in json_dict:
             raise ValueError('Missing "requests" section')
+        if sorted(json_dict.keys()) != ['parameters', 'requests']:
+            raise ValueError('unknown entries present.')
         param_dict = json_dict['parameters']
         request_list = json_dict['requests']
         base_url = param_dict.get('base_url', None)
@@ -202,10 +194,6 @@
         """
         self.stop_event.set()
         for h, t in self._threads.itervalues():
-            # Signal the queue that it should stop blocking, we don't have to
-            # wait for the queue to empty, because we may see stop_event before
-            # we see the <noop>
-            h.queue.put('<noop>')
             # And join the controlling thread
             for i in range(10):
                 t.join(self.blocking_timeout / 10.0)
@@ -223,11 +211,3 @@
             worker.queue.put(full_url, True, self.blocking_timeout)
         self.finish_queues()
         self.stop_and_join()
-
-
-def run_script(filename):
-    with open(filename, 'rb') as f:
-        content = f.read()
-    script = ActionScript.parse(content)
-    script.run()
-    return script

=== modified file 'loggerhead/tests/test_controllers.py'
--- loggerhead/tests/test_controllers.py	2011-02-10 17:01:10 +0000
+++ loggerhead/tests/test_controllers.py	2011-02-09 22:35:16 +0000
@@ -1,10 +1,3 @@
-from cStringIO import StringIO
-import logging
-
-from paste.httpexceptions import HTTPServerError
-
-from bzrlib import errors
-
 from loggerhead.apps.branch import BranchWSGIApp
 from loggerhead.controllers.annotate_ui import AnnotateUI
 from loggerhead.controllers.inventory_ui import InventoryUI
@@ -22,50 +15,15 @@
         tree.commit('')
         tree.branch.lock_read()
         self.addCleanup(tree.branch.unlock)
-        branch_app = BranchWSGIApp(tree.branch, '')
-        branch_app.log.setLevel(logging.CRITICAL)
-        # These are usually set in BranchWSGIApp.app(), which is set from env
-        # settings set by BranchesFromTransportRoot, so we fake it.
-        branch_app._static_url_base = '/'
-        branch_app._url_base = '/'
+        branch_app = BranchWSGIApp(tree.branch)
         return tree.branch, InventoryUI(branch_app, branch_app.get_history)
 
-    def consume_app(self, app, extra_environ=None):
-        env = {'SCRIPT_NAME': '/files', 'PATH_INFO': ''}
-        if extra_environ is not None:
-            env.update(extra_environ)
-        body = StringIO()
-        start = []
-        def start_response(status, headers, exc_info=None):
-            start.append((status, headers, exc_info))
-            return body.write
-        extra_content = list(app(env, start_response))
-        body.writelines(extra_content)
-        return start[0], body.getvalue()
-
     def test_get_filelist(self):
         bzrbranch, inv_ui = self.make_bzrbranch_and_inventory_ui_for_tree_shape(
             ['filename'])
         inv = bzrbranch.repository.get_inventory(bzrbranch.last_revision())
         self.assertEqual(1, len(inv_ui.get_filelist(inv, '', 'filename')))
 
-    def test_smoke(self):
-        bzrbranch, inv_ui = self.make_bzrbranch_and_inventory_ui_for_tree_shape(
-            ['filename'])
-        start, content = self.consume_app(inv_ui)
-        self.assertEqual(('200 OK', [('Content-Type', 'text/html')], None),
-                         start)
-        self.assertContainsRe(content, 'filename')
-
-    def test_no_content_for_HEAD(self):
-        bzrbranch, inv_ui = self.make_bzrbranch_and_inventory_ui_for_tree_shape(
-            ['filename'])
-        start, content = self.consume_app(inv_ui,
-                            extra_environ={'REQUEST_METHOD': 'HEAD'})
-        self.assertEqual(('200 OK', [('Content-Type', 'text/html')], None),
-                         start)
-        self.assertEqual('', content)
-
 
 class TestRevisionUI(BasicTests):
 

=== modified file 'loggerhead/tests/test_load_test.py'
--- loggerhead/tests/test_load_test.py	2011-02-10 00:49:06 +0000
+++ loggerhead/tests/test_load_test.py	2011-02-10 00:23:33 +0000
@@ -79,14 +79,6 @@
         self.assertEqual([('item', True, 1.0), ('next-item', True, 1.0)],
                          rt.stats)
 
-    def test_step_next_does_nothing_for_noop(self):
-        rt = NoopRequestWorker('id')
-        rt.queue.put('item')
-        rt.step_next()
-        rt.queue.put('<noop>')
-        rt.step_next()
-        self.assertEqual([('item', True, 1.0)], rt.stats)
-
     def test_step_next_will_timeout(self):
         # We don't want step_next to block forever
         rt = NoopRequestWorker('id', blocking_time=0.001)
@@ -175,8 +167,9 @@
             load_test.ActionScript.parse, '{"parameters": {}}')
         self.assertRaises(ValueError,
             load_test.ActionScript.parse, '{"requests": []}')
-        load_test.ActionScript.parse(
-            '{"parameters": {}, "requests": [], "comment": "section"}')
+        self.assertRaises(ValueError,
+            load_test.ActionScript.parse,
+                '{"parameters": {}, "requests": [], "garbage": "section"}')
         script = load_test.ActionScript.parse(
             empty_script)
         self.assertIsNot(None, script)
@@ -306,32 +299,3 @@
                           ("fourth", True)],
                          [(s[0].rsplit('/', 1)[1], s[1])
                           for s in worker.stats])
-
-
-class TestRunScript(tests.TestCaseWithTransport):
-
-    def setUp(self):
-        super(TestRunScript, self).setUp()
-        self.transport_readonly_server = http_server.HttpServer
-
-    def test_run_script(self):
-        self.build_tree(['file1', 'file2', 'file3', 'file4'])
-        url = self.get_readonly_url()
-        self.build_tree_contents([('localhost.script', """{
-    "parameters": {"base_url": "%s", "blocking_timeout": 0.1},
-    "requests": [
-        {"thread": "1", "relpath": "file1"},
-        {"thread": "2", "relpath": "file2"},
-        {"thread": "1", "relpath": "file3"},
-        {"thread": "2", "relpath": "file4"}
-    ]
-}""" % (url,))])
-        script = load_test.run_script('localhost.script')
-        worker = script._threads["1"][0]
-        self.assertEqual([("file1", True), ('file3', True)],
-                         [(s[0].rsplit('/', 1)[1], s[1])
-                          for s in worker.stats])
-        worker = script._threads["2"][0]
-        self.assertEqual([("file2", True), ("file4", True)],
-                         [(s[0].rsplit('/', 1)[1], s[1])
-                          for s in worker.stats])

